<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CmdRobotAddToolShape</name>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="240"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="241"/>
        <source>Add tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="242"/>
        <source>Add a tool shape to the robot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotConstraintAxle</name>
    <message>
        <location filename="../../Command.cpp" line="163"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="164"/>
        <source>Place robot...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="165"/>
        <source>Place a robot (experimental!)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="55"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="56"/>
        <source>Create trajectory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="57"/>
        <source>Create a new empty trajectory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotEdge2Trac</name>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="360"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="361"/>
        <source>Edge to Trajectory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="362"/>
        <source>Generate a Trajectory from a set of edges</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
        <location filename="../../CommandExport.cpp" line="46"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandExport.cpp" line="47"/>
        <source>Kuka compact subroutine...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandExport.cpp" line="48"/>
        <source>Export the trajectory as a compact KRL subroutine.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotExportKukaFull</name>
    <message>
        <location filename="../../CommandExport.cpp" line="121"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandExport.cpp" line="122"/>
        <source>Kuka full subroutine...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandExport.cpp" line="123"/>
        <source>Export the trajectory as a full KRL subroutine.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="192"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="193"/>
        <source>Kuka IR125</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="194"/>
        <source>Insert a Kuka IR125 into the document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="97"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="98"/>
        <source>Kuka IR16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="99"/>
        <source>Insert a Kuka IR16 into the document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="145"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="146"/>
        <source>Kuka IR210</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="147"/>
        <source>Insert a Kuka IR210 into the document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="46"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="47"/>
        <source>Kuka IR500</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="48"/>
        <source>Insert a Kuka IR500 into the document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="89"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="90"/>
        <source>Insert in trajectory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="91"/>
        <source>Insert robot Tool location into trajectory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="158"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="159"/>
        <source>Insert in trajectory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="160"/>
        <source>Insert preselection position into trajectory (W)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
        <location filename="../../Command.cpp" line="110"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="111"/>
        <location filename="../../Command.cpp" line="112"/>
        <source>Move to home</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="235"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="236"/>
        <source>Set default orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="238"/>
        <source>Set the default orientation for subsequent commands for waypoint creation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="279"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="280"/>
        <source>Set default values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="281"/>
        <source>Set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotSetHomePos</name>
    <message>
        <location filename="../../Command.cpp" line="51"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="52"/>
        <location filename="../../Command.cpp" line="53"/>
        <source>Set the home position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotSimulate</name>
    <message>
        <location filename="../../Command.cpp" line="211"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="212"/>
        <source>Simulate a trajectory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="213"/>
        <source>Run a simulation on a trajectory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="483"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="484"/>
        <source>Trajectory compound...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="485"/>
        <source>Group and connect some trajectories to one</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="426"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="427"/>
        <source>Dress-up trajectory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="429"/>
        <source>Create a dress-up object which overrides some aspects of a trajectory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
        <location filename="../../Workbench.cpp" line="51"/>
        <source>Trajectory tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Workbench.cpp" line="52"/>
        <source>Robot tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Workbench.cpp" line="53"/>
        <source>Insert Robot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="260"/>
        <location filename="../../CommandTrajectory.cpp" line="106"/>
        <location filename="../../CommandTrajectory.cpp" line="173"/>
        <location filename="../../CommandTrajectory.cpp" line="192"/>
        <location filename="../../CommandTrajectory.cpp" line="464"/>
        <location filename="../../Command.cpp" line="71"/>
        <location filename="../../Command.cpp" line="130"/>
        <location filename="../../Command.cpp" line="235"/>
        <location filename="../../CommandExport.cpp" line="62"/>
        <location filename="../../CommandExport.cpp" line="137"/>
        <source>Wrong selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="72"/>
        <source>Select one Robot to set home position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="131"/>
        <source>Select one Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="107"/>
        <location filename="../../Command.cpp" line="236"/>
        <location filename="../../CommandExport.cpp" line="63"/>
        <location filename="../../CommandExport.cpp" line="138"/>
        <source>Select one Robot and one Trajectory object.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="243"/>
        <source>Trajectory not valid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="244"/>
        <source>You need at least two waypoints in a trajectory to simulate.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandExport.cpp" line="89"/>
        <location filename="../../CommandExport.cpp" line="164"/>
        <source>KRL file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandExport.cpp" line="90"/>
        <location filename="../../CommandExport.cpp" line="165"/>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandExport.cpp" line="92"/>
        <location filename="../../CommandExport.cpp" line="167"/>
        <source>Export program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandInsertRobot.cpp" line="261"/>
        <source>Select one robot and one shape or VRML object.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="174"/>
        <location filename="../../CommandTrajectory.cpp" line="193"/>
        <source>Select one Trajectory object.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="201"/>
        <source>No preselection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="202"/>
        <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="294"/>
        <source>Set default speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="295"/>
        <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="308"/>
        <source>Set default continuity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="309"/>
        <source>continuous ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="322"/>
        <source>Set default acceleration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="323"/>
        <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CommandTrajectory.cpp" line="465"/>
        <source>Select the Trajectory which you want to dress up.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ViewProviderTrajectory.cpp" line="145"/>
        <source>Modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Workbench.cpp" line="74"/>
        <source>No robot files installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Workbench.cpp" line="75"/>
        <source>Please visit %1 and copy the files to %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="20"/>
        <source>Simulation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="58"/>
        <source>|&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="89"/>
        <source>&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="151"/>
        <source>|&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="182"/>
        <source>&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="213"/>
        <source>&gt;|</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="272"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="277"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="282"/>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="287"/>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TrajectorySimulate.ui" line="292"/>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
        <location filename="../../TaskEdge2TracParameter.cpp" line="42"/>
        <source>TaskEdge2TracParameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskEdge2TracParameter.ui" line="29"/>
        <source>Hide / Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskEdge2TracParameter.ui" line="47"/>
        <source>Edges: 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskEdge2TracParameter.ui" line="61"/>
        <source>Cluster: 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskEdge2TracParameter.ui" line="72"/>
        <source>Sizing Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskEdge2TracParameter.ui" line="103"/>
        <source>Use orientation of edge</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
        <location filename="../../TaskRobot6Axis.ui" line="22"/>
        <source>A1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobot6Axis.ui" line="69"/>
        <source>A2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobot6Axis.ui" line="116"/>
        <source>A3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobot6Axis.ui" line="163"/>
        <source>A4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobot6Axis.ui" line="210"/>
        <source>A5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobot6Axis.ui" line="257"/>
        <source>A6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobot6Axis.ui" line="313"/>
        <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobot6Axis.ui" line="329"/>
        <source>Tool: (0,0,400,0,0,0)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobot6Axis.cpp" line="41"/>
        <source>TaskRobot6Axis</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
        <location filename="../../TaskRobotControl.cpp" line="36"/>
        <source>TaskRobotControl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="37"/>
        <source>X+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="56"/>
        <source>Y+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="75"/>
        <source>Z+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="94"/>
        <source>A+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="113"/>
        <source>B+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="132"/>
        <source>C+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="151"/>
        <source>X-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="170"/>
        <source>Y-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="189"/>
        <source>Z-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="208"/>
        <source>A-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="227"/>
        <source>B-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="246"/>
        <source>C-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="258"/>
        <source>Tool 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="263"/>
        <source>Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="268"/>
        <source>Base 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="273"/>
        <source>Base</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="278"/>
        <source>World</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="287"/>
        <source>50mm / 5°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="292"/>
        <source>20mm / 2°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="297"/>
        <source>10mm / 1°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="302"/>
        <source>5mm / 0.5°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotControl.ui" line="307"/>
        <source>1mm / 0.1°</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
        <location filename="../../TaskRobotMessages.cpp" line="35"/>
        <source>TaskRobotMessages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskRobotMessages.ui" line="20"/>
        <source>clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
        <location filename="../../TaskTrajectory.ui" line="58"/>
        <source>|&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="89"/>
        <source>&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="151"/>
        <source>|&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="182"/>
        <source>&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="213"/>
        <source>&gt;|</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="254"/>
        <source>10 ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="259"/>
        <source>50 ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="264"/>
        <source>100 ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="269"/>
        <source>500 ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="274"/>
        <source>1 s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="291"/>
        <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="317"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="322"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="327"/>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="332"/>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.ui" line="337"/>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectory.cpp" line="39"/>
        <source>Trajectory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="42"/>
        <source>Dress Up Parameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="20"/>
        <source>Speed &amp; Acceleration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="29"/>
        <source>Speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="55"/>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="92"/>
        <source>Use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="66"/>
        <source>Accel:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="102"/>
        <source>Don&apos;t change Cont</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="107"/>
        <source>Continues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="112"/>
        <source>Discontinues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="127"/>
        <source>Position and Orientation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="159"/>
        <source>Don&apos;t change Position &amp; Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="164"/>
        <source>Use Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="169"/>
        <source>Add Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskTrajectoryDressUpParameter.ui" line="174"/>
        <source>Add Orientation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="../../Workbench.cpp" line="47"/>
        <source>Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Workbench.cpp" line="48"/>
        <source>Insert Robots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Workbench.cpp" line="49"/>
        <source>&amp;Robot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Workbench.cpp" line="50"/>
        <source>Export trajectory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
